@@ -20,15 +20,8 @@
 #include "atkeditabletext.h"
 
 
-struct _AtkEditableTextIfaceClass
-{
-  GObjectClass parent;
-};
-
-typedef struct _AtkEditableTextIfaceClass AtkEditableTextIfaceClass;
-
 GType
-atk_editable_text_get_type ()
+atk_editable_text_get_type (void)
 {
   static GType type = 0;
 
